@@ -4,6 +4,7 @@
 //! represents an approximate amount of time since the last Entry was created.
 use {
     crate::poh::Poh,
+    crossbeam_channel::{Receiver, Sender},
     dlopen::symbor::{Container, SymBorApi, Symbol},
     dlopen_derive::SymBorApi,
     log::*,
@@ -36,7 +37,6 @@ use {
         ffi::OsStr,
         sync::{
             atomic::{AtomicUsize, Ordering},
-            mpsc::{Receiver, Sender},
             Arc, Mutex, Once,
         },
         thread::{self, JoinHandle},
@@ -904,8 +904,17 @@ pub fn create_random_ticks(num_ticks: u64, max_hashes_per_tick: u64, mut hash: H
 
 /// Creates the next Tick or Transaction Entry `num_hashes` after `start_hash`.
 pub fn next_entry(prev_hash: &Hash, num_hashes: u64, transactions: Vec<Transaction>) -> Entry {
-    assert!(num_hashes > 0 || transactions.is_empty());
     let transactions = transactions.into_iter().map(Into::into).collect::<Vec<_>>();
+    next_versioned_entry(prev_hash, num_hashes, transactions)
+}
+
+/// Creates the next Tick or Transaction Entry `num_hashes` after `start_hash`.
+pub fn next_versioned_entry(
+    prev_hash: &Hash,
+    num_hashes: u64,
+    transactions: Vec<VersionedTransaction>,
+) -> Entry {
+    assert!(num_hashes > 0 || transactions.is_empty());
     Entry {
         num_hashes,
         hash: next_hash(prev_hash, num_hashes, &transactions),
@@ -923,7 +932,9 @@ mod tests {
             pubkey::Pubkey,
             signature::{Keypair, Signer},
             system_transaction,
-            transaction::{Result, SanitizedTransaction, TransactionError, VersionedTransaction},
+            transaction::{
+                DisabledAddressLoader, Result, SanitizedTransaction, VersionedTransaction,
+            },
         },
     };
 
@@ -1007,9 +1018,12 @@ mod tests {
                             versioned_tx.message.hash()
                         };
 
-                    SanitizedTransaction::try_create(versioned_tx, message_hash, None, |_| {
-                        Err(TransactionError::UnsupportedVersion)
-                    })
+                    SanitizedTransaction::try_create(
+                        versioned_tx,
+                        message_hash,
+                        None,
+                        &DisabledAddressLoader,
+                    )
                 }?;
 
                 Ok(sanitized_tx)
